summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--build-aux/hydra/demo-os.scm8
1 files changed, 6 insertions, 2 deletions
diff --git a/build-aux/hydra/demo-os.scm b/build-aux/hydra/demo-os.scm
index e36a9ca17d..32c6fa3abf 100644
--- a/build-aux/hydra/demo-os.scm
+++ b/build-aux/hydra/demo-os.scm
@@ -44,9 +44,13 @@
  (timezone "Europe/Paris")
  (locale "en_US.UTF-8")
  (file-systems
   ;; We don't provide a file system for /, but that's OK because the VM build
   ;; code will automatically declare the / file system for us.
-  (list ;; %fuse-control-file-system   ; needs fuse.ko
+  (list (file-system
+          (mount-point "/")
+          (device "dummy")
+          (type "dummy"))
+        ;; %fuse-control-file-system   ; needs fuse.ko
         %binary-format-file-system))
  (users (list (user-account
                (name "guest")
@@ -44,9 +44,13 @@
  (locale "en_US.UTF-8")
  (file-systems
-  ;; We don't provide a file system for /, but that's OK because the VM build
+  ;; We provide a dummy file system for /, but that's OK because the VM build
   ;; code will automatically declare the / file system for us.